function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import { defineCustomEventTarget, Event } from 'event-target-shim';
import { NativeModules } from 'react-native';
import { deepClone } from './RTCUtil';
const {
  WebRTCModule
} = NativeModules;
const MEDIA_STREAM_TRACK_EVENTS = ['ended', 'mute', 'unmute'];

class MediaStreamTrack extends defineCustomEventTarget(...MEDIA_STREAM_TRACK_EVENTS) {
  constructor(info) {
    super();

    _defineProperty(this, "_constraints", void 0);

    _defineProperty(this, "_enabled", void 0);

    _defineProperty(this, "_settings", void 0);

    _defineProperty(this, "_muted", void 0);

    _defineProperty(this, "_peerConnectionId", void 0);

    _defineProperty(this, "_readyState", void 0);

    _defineProperty(this, "id", void 0);

    _defineProperty(this, "kind", void 0);

    _defineProperty(this, "label", '');

    _defineProperty(this, "remote", void 0);

    this._constraints = info.constraints || {};
    this._enabled = info.enabled;
    this._settings = info.settings || {};
    this._muted = false;
    this._peerConnectionId = info.peerConnectionId;
    this._readyState = info.readyState;
    this.id = info.id;
    this.kind = info.kind;
    this.remote = info.remote;
  }

  get enabled() {
    return this._enabled;
  }

  set enabled(enabled) {
    if (enabled === this._enabled) {
      return;
    }

    WebRTCModule.mediaStreamTrackSetEnabled(this.id, !this._enabled);
    this._enabled = !this._enabled;
  }

  get muted() {
    return this._muted;
  }

  get readyState() {
    return this._readyState;
  }

  stop() {
    WebRTCModule.mediaStreamTrackSetEnabled(this.id, false);
    this._readyState = 'ended'; // TODO: save some stopped flag?
  }
  /**
   * Private / custom API for switching the cameras on the fly, without the
   * need for adding / removing tracks or doing any SDP renegotiation.
   *
   * This is how the reference application (AppRTCMobile) implements camera
   * switching.
   */


  _switchCamera() {
    if (this.remote) {
      throw new Error('Not implemented for remote tracks');
    }

    if (this.kind !== 'video') {
      throw new Error('Only implemented for video tracks');
    }

    WebRTCModule.mediaStreamTrackSwitchCamera(this.id);
  }

  _setVideoEffect(name) {
    if (this.remote) {
      throw new Error('Not implemented for remote tracks');
    }

    if (this.kind !== 'video') {
      throw new Error('Only implemented for video tracks');
    }

    WebRTCModule.mediaStreamTrackSetVideoEffect(this.id, name);
  }
  /**
   * Internal function which is used to set the muted state on remote tracks and
   * emit the mute / unmute event.
   *
   * @param muted Whether the track should be marked as muted / unmuted.
   */


  _setMutedInternal(muted) {
    if (!this.remote) {
      throw new Error('Track is not remote!');
    }

    this._muted = muted;
    this.dispatchEvent(new Event(muted ? 'mute' : 'unmute'));
  }

  applyConstraints() {
    throw new Error('Not implemented.');
  }

  clone() {
    throw new Error('Not implemented.');
  }

  getCapabilities() {
    throw new Error('Not implemented.');
  }

  getConstraints() {
    return deepClone(this._constraints);
  }

  getSettings() {
    return deepClone(this._settings);
  }

  release() {
    WebRTCModule.mediaStreamTrackRelease(this.id);
  }

}

export default MediaStreamTrack;
//# sourceMappingURL=MediaStreamTrack.js.map